@@ -23,4 +23,8 @@ def error(text):
   return Fore.RED + text + Fore.RESET
 
 def success(text):
-  return Fore.GREEN + text + Fore.RESET
\ No newline at end of file
+  return Fore.GREEN + text + Fore.RESET
+
+def die(message):
+  print(error(message))
+  exit()
\ No newline at end of file
